@@ -1,10 +1,16 @@
 # Copyright 2019-2021 Cambridge Quantum Computing
 #
-# You may not use this file except in compliance with the Licence.
-# You may obtain a copy of the Licence in the LICENCE file accompanying
-# these documents or at:
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-#     https://cqcl.github.io/pytket/build/html/licence.html
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 
 """Methods to allow conversion between Qiskit and pytket circuit classes
@@ -14,7 +20,6 @@ from typing import (
     Dict,
     List,
     Optional,
-    Sequence,
     Union,
     Any,
     Iterable,
@@ -24,8 +29,8 @@ from typing import (
     TYPE_CHECKING,
 )
 from inspect import signature
-import sympy  # type: ignore
 import warnings
+import sympy  # type: ignore
 import qiskit.circuit.library.standard_gates as qiskit_gates  # type: ignore
 from qiskit import (
     ClassicalRegister,
@@ -195,12 +200,12 @@ class CircuitBuilder:
     def __init__(
         self,
         qregs: List[QuantumRegister],
-        cregs: List[ClassicalRegister] = [],
+        cregs: Optional[List[ClassicalRegister]] = None,
         name: Optional[str] = None,
         phase: Optional[float] = 0.0,
     ):
         self.qregs = qregs
-        self.cregs = cregs
+        self.cregs = [] if cregs is None else cregs
         self.tkc = Circuit(name=name)
         self.tkc.add_phase(phase)
         self.qregmap = {}
@@ -208,7 +213,7 @@ class CircuitBuilder:
             tk_reg = self.tkc.add_q_register(reg.name, len(reg))
             self.qregmap.update({reg: tk_reg})
         self.cregmap = {}
-        for reg in cregs:
+        for reg in self.cregs:
             tk_reg = self.tkc.add_c_register(reg.name, len(reg))
             self.cregmap.update({reg: tk_reg})
 
